<?php
/**
 * @file
 * Contains \Drupal\docbinder\Controller\DocbinderController.
 */
/**
 * Created by PhpStorm.
 * User: christian.bruhn
 * Date: 07.09.18
 * Time: 10:57
 */

namespace Drupal\docbinder\Controller;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\AlertCommand;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\TempStore\PrivateTempStoreFactory;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\docbinder\Ajax\AddFileCommand;
use Drupal\docbinder\Ajax\RemoveFileCommand;
use Drupal\docbinder\Ajax\UpdateFileCountCommand;
use Drupal\file\Entity\File;


class DocBinderController extends ControllerBase {

  /**
   * The tempstore.
   *
   * @var \Drupal\Core\TempStore\SharedTempStore
   */
  protected $tempStore;

  /**
   * Constructs a new DocBinder controller.
   *
   * @param \Drupal\Core\TempStore\PrivateTempStoreFactory $temp_store_factory
   *   The tempstore factory.
   */
  public function __construct(PrivateTempStoreFactory $temp_store_factory) {
    // For "mymodule_name," any unique namespace will do
    $this->tempStore = $temp_store_factory->get('docbinder');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('tempstore.private')
    );
  }

  public function binderPage() {
    // .. build $content
    $this->tempStore = \Drupal::service('tempstore.private')->get('docbinder');
    $html = '<div id="docbinder-block"><p>Your collection</p><ul id="docbinder-block-files">';
    foreach ($this->tempStore->get('files') as $fid => $file) {
      /** @var File $file **/
      $html .= '<li id="docbinder-file-' . $file->id() . '">' . $file->getFilename() . ' <a class="use-ajax" href="/docbinder/remove/' . $fid . '" style="color:red;">del</a></li>';
    }
    $html .= '</ul></div>';

    return [
      '#theme' => 'docbinder_page',
      '#files' => $this->tempStore->get('files'),
    ];

//    return array(
//      '#type' => 'markup',
//      '#markup' => $html,
//      '#cache' => array(
//        'max-age' => 0,
//      ),
//      '#attached' => array(
//        'library' => array(
//          'docbinder/docbinder.commands',
//        ),
//      ),
//    );
  }

  public function pageTitle() {
    return "Download Collection";
  }

  public function addFile(File $file) {
    $response = new AjaxResponse();

    $files = $this->tempStore->get('files');
    if (array_key_exists($file->id(), $files)) {
      // File already in list
      $this->tempStore->set('statusCode', 304);
      #$response->addCommand(new AddFileCommand($this->tempStore));
      $response->addCommand(new UpdateFileCountCommand($this->tempStore));
    }
    else {
      $files[$file->id()] = $file;
      $this->tempStore->set('files', $files);
      $this->tempStore->set('addedLast', $file->id());
      $this->tempStore->set('statusCode', 200);
      #$response->addCommand(new AddFileCommand($this->tempStore));
      $response->addCommand(new UpdateFileCountCommand($this->tempStore));
    }

    #$response->addCommand(new AddFileCommand($file));
    return $response;
  }

  public function removeFile(File $file) {
    $response = new AjaxResponse();

    $files = $this->tempStore->get('files');
    if (array_key_exists($file->id(), $files)) {
      // File is in list
      unset($files[$file->id()]);
      $this->tempStore->set('files', $files);
      $this->tempStore->set('removedLast', $file->id());
      $this->tempStore->set('statusCode', 200);
      $response->addCommand(new RemoveFileCommand($this->tempStore));
      $response->addCommand(new UpdateFileCountCommand($this->tempStore));
    }
    else {
      $this->tempStore->set('statusCode', 404);
      #$response->addCommand(new RemoveFileCommand($this->tempStore));
      $response->addCommand(new UpdateFileCountCommand($this->tempStore));
    }

    #$response->addCommand(new AddFileCommand($file));
    return $response;
  }
}